@@ -1611,6 +1611,27 @@ class Api(object):
     self._CheckForTwitterError(data)
     return Status.NewFromJsonDict(data)
 
+  def reTweet(self, retweet_status_id=None):
+    '''Post retweet of status id
+
+    The twitter.Api instance must be authenticated.
+
+    Args:
+      retweet_status_id:
+        The ID of an existing status that is to be retweeted
+    Returns:
+      A twitter.Status instance representing the message posted.
+    '''
+    if not self._username:
+      raise TwitterError("The twitter.Api instance must be authenticated.")
+
+    url = self._base_url + 'statuses/retweet/%s.json' %retweet_status_id
+    
+    json = self._FetchUrl(url, post_data="")
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return Status.NewFromJsonDict(data)
+
   def PostUpdates(self, status, continuation=None, **kwargs):
     '''Post one or more twitter status messages from the authenticated user.
 
