@@ -399,11 +399,14 @@ class Witter():
                 self.theme = config.get("UI", "theme")
                 gestures = config.get("UI","gestures_enabled")
                 emailnotifications = config.get("UI","notifications_enabled")
-                if (gestures == 'True'):
+                if (gestures == "True"):
                     self.gestures = True
+                    print "gestures enabled"
                 else:
-                    self.gestures= False
-                if (emailnotifications == 'True'):
+                    self.gestures = False
+                    print "gestures disabled"
+                     
+                if (emailnotifications == "True"):
                     self.emailnotifications = True
                 else:
                     self.emailnotifications = False    
@@ -535,7 +538,7 @@ class Witter():
             else:
                 f.write("gestures_enabled = False\n")
             if self.emailnotifications:
-                f.write("notifcations_enabled = True\n")
+                f.write("notifications_enabled = True\n")
             else:
                 f.write("notifications_enabled = False\n")
             f.write("[refresh_interval]\n")
